@@ -1,15 +1,13 @@
-import pkg_resources
-
 from .fields import SQLAlchemyConnectionField
-from .types import SQLAlchemyObjectType
-from .utils import get_query
 from .sql_mutation import (
     SQLAlchemyUpdateMutation,
     SQLAlchemyCreateMutation,
     SQLAlchemyDeleteMutation,
 )
+from .types import SQLAlchemyObjectType
+from .utils import get_query
 
-__version__ = "3.2.15"
+__version__ = "3.3.3"
 
 __all__ = [
     "__version__",
@@ -20,6 +18,3 @@ __all__ = [
     "SQLAlchemyDeleteMutation",
     "get_query",
 ]
-
-if pkg_resources.get_distribution("SQLAlchemy").parsed_version.release < (1, 4):
-    raise Exception("Use SQLAlchemy version > 1.4")
