@@ -68,8 +68,18 @@ class UnsortedSQLAlchemyConnectionField(ConnectionField):
         resolved,
     ):
         if resolved is None:
+            edge_type = connection_type.Edge
+            node_type = edge_type.node.type
+
+            query = await cls.get_query(
+                model=model,
+                info=info,
+                cls_name=node_type.__name__,
+                **args,
+            )
+
             connection = await connection_from_query(
-                cls,
+                query,
                 info=info,
                 model=model,
                 args=args,
@@ -318,12 +328,11 @@ class FilterConnectionField(SQLAlchemyConnectionField):
             # plain strings
             for item in sort:
                 if isinstance(item, (EnumValue, enum.Enum)):
-                    sort_args.append(item.value.nullslast())
+                    sort_args.append(item.value)
                 else:
-                    sort_args.append(item.nullslast())
+                    sort_args.append(item)
 
-            if hasattr(model, "id"):
-                sort_args.append(model.id)
+            sort_args.extend(sa.inspect(model).primary_key)
 
             query = query.order_by(*sort_args)
         return query
